package VMOMI::HostSnmpAgentCapability;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
